/*-----------------------------------------------------------------------
cdgprmainprogram.sas

SAS program to implement the estimation methodology developed in
'The productivity advantages of large cities: Distinguishing agglomeration from firm selection'
by Pierre-Philippe Combes, Gilles Duranton, Laurent Gobillon, Diego Puga, and Sbastien Roux. 

It estimates the combination of left-truncation, shift and dilation that, 
when applied to one distribution, best approximates a second distribution.

See http:/diegopuga.org/data/selectagg/ for documentation.
-----------------------------------------------------------------------*/

/***   EDIT LOCAL SETTINGS HERE   ***/
%let basedir=d:\mydir; /* base directory */
%let data=cdgprdata; /* source data set (extension to be sas7bdat) */
%let variables=tfp_ols; /* variable name (or variable names separated by spaces) */
%let trim=1; /* defines the percentage of observations to be trimmed on each 
extreme of each of the two distributions; set 1 for 1%, 2 for 2% etc */

/*** NOTHING MORE TO CHANGE BELOW ***/
libname cdgpr "&basedir";

%include "&basedir/cdgprmacros.sas";

%macro main;
	%let k=1;
	%let name=%scan(&variables,&k);

	%estimt(&name,cdgpr.&data,cat,1,2,&trim);

	data cdgpr.results&data;
		set resultff;
	run;

	%loop:
		%let k=%eval(&k+1);
		%let name=%scan(&variables,&k);

		%if %length(&name) eq 0 %then
			%goto leave;

		%estimt(&name,cdgpr.&data,cat,1,2,&trim);

		data cdgpr.results&data;
			set cdgpr.results&data resultff;
		run;

		%goto loop;

	%leave:
%mend main;

%main;

proc print data=cdgpr.results&data;
run;

quit;
